==> cra-template-rb-0.0.3.tgz: package/template/README.md <==
# UNDER DEVELOPMENT!

<img width="914" alt="React Boilerplate Meets CRA" src="https://user-images.githubusercontent.com/3495307/79694949-7b098b00-827c-11ea-8f8b-cb4b9e673b5c.png" align="center">
<br />

<div align="center">

```html
Create React App template of React Boilerplate
```

</div>
<br />
<div align="center">Crafted for <strong>highly scalable</strong>, <strong>easily maintainable</strong> and <strong>highly performant</strong> React.js applications with a focus on <strong>best DX</strong> and <strong>best practices</strong>.</div>

<br />

<div align="center">
  <a href="https://github.com/Can-Sahin/cra-template-react-boilerplate/actions?query=workflow%3Abuild">
    <img src="https://github.com/Can-Sahin/cra-template-react-boilerplate/workflows/build/badge.svg" alt="Build Status" />
  </a>
  <a href="https://github.com/Can-Sahin/cra-template-react-boilerplate/actions?query=workflow%3Atests">
    <img src="https://github.com/Can-Sahin/cra-template-react-boilerplate/workflows/tests/badge.svg" alt="Tests Status" />
  </a>
  <a href="https://coveralls.io/github/Can-Sahin/cra-template-react-boilerplate">
    <img src="https://coveralls.io/repos/github/Can-Sahin/cra-template-react-boilerplate/badge.svg?branch=master" alt="Coverage" />
  </a>
  <a href="https://david-dm.org/can-sahin/cra-template-react-boilerplate">
    <img src="https://david-dm.org/can-sahin/cra-template-react-boilerplate.svg" alt="Dependency Status" />
  </a>
</a>
</div>
<div align="center">
  <a href="https://opencollective.com/react-boilerplate">
    <img src="https://opencollective.com/react-boilerplate/backers/badge.svg" alt="Backers" />
  </a>
  <a href="https://opencollective.com/react-boilerplate/">
    <img src="https://opencollective.com/react-boilerplate/sponsors/badge.svg" alt="Sponsors" />
  </a>
  <img src="https://img.shields.io/github/license/can-sahin/cra-template-react-boilerplate" alt="License" />
</div>

<br />

---

The official [Create React App](https://github.com/facebook/create-react-app) template of [React Boilerplate](https://github.com/react-boilerplate/react-boilerplate)
![](https://img.shields.io/github/stars/react-boilerplate/react-boilerplate?style=flat)
![](https://img.shields.io/github/contributors/react-boilerplate/react-boilerplate)

Start your `create-react-app` projects in seconds with the best, industry-standard tools and practices made ready for you.

**📝 Documentation: [GitBook](https://cansahin.gitbook.io/cra-template-react-boilerplate/)**

---

## Install & Start

```sh
npx create-react-app --template cra-template-react-boilerplate my-app # Create React App with the template
cd my-app
npm start # Check the example app
npm run cleanExampleApp # Ready to start your project!
```

## Features

<dl>

  <dt>Predictable state management</dt>
  <dd>Unidirectional data flow allows for change logging and time travel debugging.</dd>

  <dt>Instant feedback</dt>
  <dd>Enjoy the best DX (Developer eXperience) and code your app at the speed of thought! Your saved changes to the CSS and JS are reflected instantaneously without refreshing the page. Preserve application state even when you update something in the underlying code!</dd>

  <dt>Next generation CSS</dt>
  <dd>Write composable CSS that's co-located with your components for complete modularity. Unique generated class names keep the specificity low while eliminating style clashes. Ship only the styles that are on the page for the best performance.</dd>

  <dt>Industry-standard routing</dt>
  <dd>It's natural to want to add pages (e.g. `/about`) to your application, and routing makes this possible.</dd>

  <dt>Industry-standard i18n internationalization support</dt>
  <dd>Scalable apps need to support multiple languages, easily add and support multiple languages.</dd>

  <dt>Typescript</dt>
  <dd>Typescript is the key to scalability. Build self-documented code, easy-to-debug code and create maintainable large applications and codebases with a highly productive development experience.</dd>

  <dt>Quick scaffolding</dt>
  <dd>Create components, containers, routes, selectors and sagas - and their tests - right from the CLI!</dd>

  <dt>Static code analysis</dt>
  <dd>Focus on writing new features without worrying about formatting or code quality. With the right editor setup, your code will automatically be formatted and linted as you work.</dd>

  <dt>SEO</dt>
  <dd>We support SEO (document head tags management) for search engines that support indexing of JavaScript content. (eg. Google)</dd>
</dl>

But wait... there's more!

- _The best test setup:_ Automatically guarantee code quality and non-breaking
  changes. (Seen a react app with 100% test coverage before?)
- _The fastest fonts:_ Say goodbye to vacant text.
- _Stay fast_: Profile your app's performance from the comfort of your command
  line!

<sub><i>Keywords: Crate React App, React Boilerplate, Typescript, React.js, Redux, Hot Reloading, ESNext, Babel, react-router, Offline First, ServiceWorker, `styled-components`, redux-saga, FontFaceObserver</i></sub>

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/Can-Sahin"><img src="https://avatars2.githubusercontent.com/u/33245689" width="80px;" alt=""/><br /><sub><b>Can Sahin</b></sub></a><br /><a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Code">💻</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Documentation">📖</a> <a href="#ideas-Can-Sahin" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/pulls?q=is%3Apr+reviewed-by%3ACan-Sahin" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/receptiryaki"><img src="https://avatars0.githubusercontent.com/u/3495307" width="80px;" alt=""/><br /><sub><b>Recep Tiryaki</b></sub></a><br /><a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=receptiryaki" title="Code">💻</a> <a href="#ideas-receptiryaki" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## License

This project is licensed under the MIT license, Copyright (c) 2019 Maximilian
Stoiber. For more information see `LICENSE.md`.

==> cra-template-rb-0.0.4.tgz: package/template/README.md <==
<img width="914" alt="React Boilerplate Meets CRA" src="https://user-images.githubusercontent.com/3495307/79694949-7b098b00-827c-11ea-8f8b-cb4b9e673b5c.png" align="center">
<br />

<div align="center">

```html
Create React App template of React Boilerplate
```

</div>
<br />
<div align="center">Crafted for <strong>highly scalable</strong>, <strong>easily maintainable</strong> and <strong>highly performant</strong> React.js applications with a focus on <strong>best DX</strong> and <strong>best practices</strong>.</div>

<br />

<div align="center">
  <a href="https://github.com/Can-Sahin/cra-template-react-boilerplate/actions?query=workflow%3Abuild">
    <img src="https://github.com/Can-Sahin/cra-template-react-boilerplate/workflows/build/badge.svg" alt="Build Status" />
  </a>
  <a href="https://github.com/Can-Sahin/cra-template-react-boilerplate/actions?query=workflow%3Atests">
    <img src="https://github.com/Can-Sahin/cra-template-react-boilerplate/workflows/tests/badge.svg" alt="Tests Status" />
  </a>
  <a href="https://coveralls.io/github/Can-Sahin/cra-template-react-boilerplate">
    <img src="https://coveralls.io/repos/github/Can-Sahin/cra-template-react-boilerplate/badge.svg?branch=master" alt="Coverage" />
  </a>
  <a href="https://david-dm.org/can-sahin/cra-template-react-boilerplate">
    <img src="https://david-dm.org/can-sahin/cra-template-react-boilerplate.svg" alt="Dependency Status" />
  </a>
</a>
</div>
<div align="center">
  <a href="https://opencollective.com/react-boilerplate">
    <img src="https://opencollective.com/react-boilerplate/backers/badge.svg" alt="Backers" />
  </a>
  <a href="https://opencollective.com/react-boilerplate/">
    <img src="https://opencollective.com/react-boilerplate/sponsors/badge.svg" alt="Sponsors" />
  </a>
  <img src="https://img.shields.io/github/license/can-sahin/cra-template-react-boilerplate" alt="License" />
</div>

<br />

---

The official [Create React App](https://github.com/facebook/create-react-app) template of [React Boilerplate](https://github.com/react-boilerplate/react-boilerplate)
![](https://img.shields.io/github/stars/react-boilerplate/react-boilerplate?style=flat)
![](https://img.shields.io/github/contributors/react-boilerplate/react-boilerplate)

Start your `create-react-app` projects in seconds with the best, industry-standard tools and practices made ready for you.

**📝 Documentation:** [gitbook](https://cansahin.gitbook.io/cra-template-react-boilerplate/)

**🔗 Package:** [npm](https://www.npmjs.com/package/cra-template-rb)

---

## Install & Start

```shell
# Create React App with the template
npx create-react-app --template cra-template-rb my-app

# Check the example app
cd my-app
npm start

# Remove the example app and start your project!
npm run cleanExampleApp
```

## Features

<dl>

  <dt>Predictable state management</dt>
  <dd>Unidirectional data flow allows for change logging and time travel debugging.</dd>

  <dt>Instant feedback</dt>
  <dd>Enjoy the best DX (Developer eXperience) and code your app at the speed of thought! Your saved changes to the CSS and JS are reflected instantaneously without refreshing the page. Preserve application state even when you update something in the underlying code!</dd>

  <dt>Next generation CSS</dt>
  <dd>Write composable CSS that's co-located with your components for complete modularity. Unique generated class names keep the specificity low while eliminating style clashes. Ship only the styles that are on the page for the best performance.</dd>

  <dt>Industry-standard routing</dt>
  <dd>It's natural to want to add pages (e.g. `/about`) to your application, and routing makes this possible.</dd>

  <dt>Industry-standard i18n internationalization support</dt>
  <dd>Scalable apps need to support multiple languages, easily add and support multiple languages.</dd>

  <dt>Typescript</dt>
  <dd>Typescript is the key to scalability. Build self-documented code, easy-to-debug code and create maintainable large applications and codebases with a highly productive development experience.</dd>

  <dt>Quick scaffolding</dt>
  <dd>Create components, containers, routes, selectors and sagas - and their tests - right from the CLI!</dd>

  <dt>Static code analysis</dt>
  <dd>Focus on writing new features without worrying about formatting or code quality. With the right editor setup, your code will automatically be formatted and linted as you work.</dd>

  <dt>SEO</dt>
  <dd>We support SEO (document head tags management) for search engines that support indexing of JavaScript content. (eg. Google)</dd>
</dl>

But wait... there's more!

- _The best test setup:_ Automatically guarantee code quality and non-breaking
  changes. (Seen a react app with 100% test coverage before?)
- _The fastest fonts:_ Say goodbye to vacant text.
- _Stay fast_: Profile your app's performance from the comfort of your command
  line!

<sub><i>Keywords: Crate React App, React Boilerplate, Typescript, React.js, Redux, Hot Reloading, ESNext, Babel, react-router, Offline First, ServiceWorker, `styled-components`, redux-saga, FontFaceObserver</i></sub>

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/Can-Sahin"><img src="https://avatars2.githubusercontent.com/u/33245689" width="80px;" alt=""/><br /><sub><b>Can Sahin</b></sub></a><br /><a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Code">💻</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Documentation">📖</a> <a href="#ideas-Can-Sahin" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/pulls?q=is%3Apr+reviewed-by%3ACan-Sahin" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=Can-Sahin" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/receptiryaki"><img src="https://avatars0.githubusercontent.com/u/3495307" width="80px;" alt=""/><br /><sub><b>Recep Tiryaki</b></sub></a><br /><a href="https://github.com/cra-template-react-boilerplate/cra-template-react-boilerplate/commits?author=receptiryaki" title="Code">💻</a> <a href="#ideas-receptiryaki" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## License

This project is licensed under the MIT license, Copyright (c) 2019 Maximilian
Stoiber. For more information see `LICENSE.md`.
